/*
 * (C) Copyright 2013
 * DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include "version.h"
#include "command.h"
#include "tools.h"
#include "io.h"

/*************************************************************************************
 *  Local Variables
 *************************************************************************************/
static unsigned char monitorRunning = 0;
static Command * commandsList = 0;

/*************************************************************************************
 *  Local functions
 *************************************************************************************/
static unsigned char commandParser ( char * pBuffer )
{
	unsigned char  argc;
	char * argv[20];
	unsigned int i = 0;
	unsigned char found = 0, status = -1;

	argc = makeargv(pBuffer, sizeof(argv)/sizeof(argv[0]), argv);

	for ( i = 0; commandsList[i].command != 0; i++ )
	{
		if ( strcmp ( (char *)argv[0], commandsList[i].command ) == 0 )
		{
			if ( commandsList[i].function != 0 )
				status = commandsList[i].function(argc, argv);
			found = 1;
			break;
		}
	}

	if ( !found )
	{
		printf("Invalid command, type \"help\" for available commands\n");
	}

	return status;
}

/*************************************************************************************
 *  Global functions
 *************************************************************************************/

/*!
*****************************************************************************

 \fn void monitor (Command * commands);

 <b>Description:</b>\n
 main loop of monitor will be started and run until exit command is input

 \param[in] commands		array of Commands

******************************************************************************/
#define COMMAND_BUFFER_SIZE 256
void monitor(Command * commands)
{
	char commandBuffer[COMMAND_BUFFER_SIZE];
	unsigned char lastCommandRetureValue = 0;

	if ( commands != 0 )
	{
		commandsList=commands;
		monitorRunning = 1;

		/*Main Program Loop*/
		while ( monitorRunning )
		{
			printf("%s>", lastCommandRetureValue==0?"CMDSUCC":"CMDFAIL");
			read(commandBuffer);
			lastCommandRetureValue = commandParser(commandBuffer);
		}
	}
}

/*************************************************************************************
 *  commands functions
 *************************************************************************************/
unsigned char cmdVersion(unsigned char argc , char * argv[])
{
#ifndef VERSION
#define VERSION __DATE__
#endif
	printf("command line interface version : %s\n", VERSION );
	return 0;
}

unsigned char cmdExit(unsigned char argc , char * argv[])
{
	monitorRunning = 0;
	return 0;
}

unsigned char cmdHelp(unsigned char argc, char * argv[])
{
	unsigned int i = 0;

	if ( argc == 1 ) {
		printf("Command		 Description\n" );
		printf("======================================================================\n" );
		for ( i = 0; commandsList[i].command != 0; i++ ) {
			printf("%-16s %s\n", commandsList[i].command, commandsList[i].description );
		}
	} else if ( argc == 2 ) {
		for ( i = 0; commandsList[i].command != 0; i++ ) {
			if ( strcmp ( (char *)argv[1], commandsList[i].command ) == 0 ) {
				printf("%-16s %s\n", commandsList[i].command, commandsList[i].description );
			}
		}
	}
	return 0;
}

