/*
 * (C) Copyright 2012
 * DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include "common.h"
#include "hardware.h"
#include "gpio.h"

#define G(x) (x % 32)

static void gpio_writel(unsigned int gpio, uint32_t val, int reg)
{
	int bank = gpio / 32;

	writel(val, DVF99_GPIO_BASE + bank * DVF99_GPIO_BANKOFF + reg);
}

void gpio_enable(int gpio)
{
	gpio_writel(gpio, 1 << G(gpio), DVF99_GPIO_EN_SET);
}

void gpio_disable(int gpio)
{
	gpio_writel(gpio, 1 << G(gpio), DVF99_GPIO_EN_CLR);
}

void gpio_set_value(int gpio, int value)
{
	int reg = value ? DVF99_GPIO_DATA_SET : DVF99_GPIO_DATA_CLR;

	gpio_writel(gpio, 1 << G(gpio), reg);
}

void gpio_direction_output(int gpio, int value)
{
	gpio_writel(gpio, 1 << G(gpio), DVF99_GPIO_DIR_OUT);
	gpio_set_value(gpio, value);
}
