#!/bin/bash
#
# make bootloader images for secure boot tests
#

MKBOOTIMG=./mkbootimg

# make signed bootastic images
function make_bootastic_images()
{
	for key in 1 2 3 4 5
	do
		${MKBOOTIMG} --preloader=bootastic.bin --crc32 --sign=keys/key${key}.pem --output=tests/bootastic.img.key${key}
	done
}

# make signed u-boot images
function make_uboot_images()
{
	for key in 1 2 3 4 5
	do
		${MKBOOTIMG} --loader=u-boot.bin --loader-addr=0x41000000 --crc32 --sign=keys/key${key}.pem --patch-uboot=u-boot --output=tests/u-boot.img.key${key}
	done
}

# make full images
function make_full_images()
{
	for key in 1 2 3 4 5
	do
		${MKBOOTIMG} --preloader=bootastic.bin --loader=u-boot.bin --loader-addr=0x41000000 --crc32 --sign=keys/key${key}.pem --patch-uboot=u-boot --output=tests/bootloader.img.key${key}
	done
}

DDRCONF="mt47h64m16_25e_bl8_cl5_375"
#DDRCONF="mt41j64m16_187e_bl8_cl6_375"

make clean || exit -1
make DRAM=${DDRCONF} || exit -2

mkdir -p tests

#cp bootloader.img tests/bootloader.img.notsigned

make_bootastic_images || exit -3
make_uboot_images || exit -3
make_full_images || exit -3

echo
echo
echo "images:"
echo "-------"
TESTS=`ls tests/*`
for t in $TESTS
do
	echo "* $t"
done
