/*
 * (C) Copyright 2012
 * DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include "common.h"
#include "hardware.h"
#include "syscfg.h"

void pad_enable(unsigned int pad)
{
	uint32_t reg;
	int off = pad / 32 * 4;

	pad %= 32;

	reg = readl(DVF99_SCON_BASE + DVF99_SCON_SPCR1 + off);
	reg |= (1 << pad);
	writel(reg, DVF99_SCON_BASE + DVF99_SCON_SPCR1 + off);
}

void syscfg_set_romws(unsigned int waitstates)
{
	uint32_t reg;

	waitstates &= 1;

	reg = readl(DVF99_SCON_BASE + DVF99_SCON_GCR1);
	reg &= ~1;
	reg |= waitstates;
	writel(reg, DVF99_SCON_BASE + DVF99_SCON_GCR1);
}

void syscfg_memboot_pad_enable(void)
{
	uint32_t reg;

	reg = readl(DVF99_SCON_BASE + DVF99_SCON_GCR2);
	reg |= 1 << 0;
	writel(reg, DVF99_SCON_BASE + DVF99_SCON_GCR2);
}

void syscfg_sdram_slew_rate(int rate)
{
	uint32_t reg;

	reg = readl(DVF99_SCON_BASE + DVF99_SCON_DRAMCTL_CFG0);
	reg &= ~(3 << 8);
	reg |= (rate & 0x3) << 8;
	writel(reg, DVF99_SCON_BASE + DVF99_SCON_DRAMCTL_CFG0);
}

int syscfg_get_chip_rev(void)
{
	return readl(DVF99_SCON_BASE + DVF99_SCON_CHIP_REV);
}

void syscfg_enable_main_clk_out(void)
{
	uint32_t reg;

	reg = readl(DVF99_SCON_BASE + DVF99_SCON_GCR1);
	reg |= 0x2;
	writel(reg, DVF99_SCON_BASE + DVF99_SCON_GCR1);
}
