/*
 * (C) Copyright 2013
 * DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#ifndef __TOOLS_H__
#define __TOOLS_H__

/*!
*****************************************************************************

 \fn int strlen (const char* str);

 <b>Description:</b>\n
 Returns the length of the C string str.

 \param[in] s		The input string to length

 \return :: length in integer

******************************************************************************/
int strlen (const char* str);

/*!
*****************************************************************************

 \fn int strcmp (const char* s1, const char* s2);

 <b>Description:</b>\n
 Compares the C string s1 to the C string s2.

 \param[in] s1		C string to be compared.
 \param[in] s2		C string to be compared.

 \return :: A zero value indicates that both strings are equal.
	A value greater than zero indicates that the first character that 
        does not match has a greater value in str1 than in str2;
	And a value less than zero indicates the opposite.

******************************************************************************/
int strcmp (const char* s1, const char* s2);

/*!
*****************************************************************************

 \fn char * strncpy(char* dst, const char* src, int n);

 <b>Description:</b>\n
 Copies the first num characters of source to destination. If the end of the 
 source C string (which is signaled by a null-character) is found before num
 characters have been copied, destination is padded with zeros until a total
 of num characters have been written to it.

 \param[in] dst		Pointer to the destination is to be copied.
 \param[in] src		C string to be copied.
 \param[in] n		maximum number of characters to be copied from source.

 \return :: destination is returned

******************************************************************************/
char * strncpy(char* dst, const char* src, int n);

/*!
*****************************************************************************

 \fn char * strcpy(char* dst, const char* src);

 <b>Description:</b>\n
 Copies the C string pointed by source into the array pointed by destination, 
 including the terminating null character (and stopping at that point).

 \param[in] dst		Pointer to the destination is to be copied.
 \param[in] src		C string to be copied.

 \return :: destination is returned

******************************************************************************/
char * strcpy(char* dst, const char* src);

/*!
*****************************************************************************

 \fn int dec2int ( char* s );

 <b>Description:</b>\n
 Parse decimal value into integer, accepting with or without -+ sign

 \param[in] s		The input string to parse

 \return :: integer value parsed

******************************************************************************/
int dec2int ( char* s );

/*!
*****************************************************************************

 \fn unsigned int hex2int ( char* s );

 <b>Description:</b>\n
 Parse hexdecimal value into unsigned integer, accepting with or without 0x

 \param[in] s		The input string to parse

 \return :: unsigned integer value parsed

******************************************************************************/
unsigned int hex2int ( char* s );

/*!
*****************************************************************************

 \fn int makeargv(char * s, unsigned char argvsz, char * argv[]);

 <b>Description:</b>\n
 Tokenize buffer S into argurments and arguement count

 \param[in] s		array of cliCommands
 \param[in] argvsz	number Of commands
 \param[in] argv	version string

 \return :: number of argurment tokenized

******************************************************************************/
int makeargv(char * s, unsigned char argvsz, char * argv[]);

#endif /* __TOOLS_H__ */
