/*
 * (C) Copyright 2012 DSP Group
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

#include <common.h>
#include <asm/io.h>
#include <asm/arch/pads.h>
#include <asm/arch/hardware.h>

struct pads {
	char *name;
	int enable_bit;
	int location_bit;
};

#define __stringify_1(x)	#x
#define __stringify(x)		__stringify_1(x)

#define PADS(_name, _bit)                   \
	static struct pads pads_##_name = {        \
		.name = __stringify(_name), \
		.enable_bit = _bit,         \
		.location_bit = -1,         \
	}

#define PADS_LOC(_name, _bit, _loc)         \
	static struct pads pads_##_name = {        \
		.name = __stringify(_name), \
		.enable_bit = _bit,         \
		.location_bit = _loc,       \
	}

PADS(rfapu, 31);
PADS(mlse, 30);
PADS(pmu, 29);
PADS(digmic, 28);
PADS(fc, 27);
PADS(uart1, 26);
PADS_LOC(uart2, 25, 24);
PADS(tdm1, 23);
PADS(tdm2, 22);
PADS(spi1, 20);
PADS(spi2, 19);
PADS(i2c1, 17);
PADS(i2c2, 16);
PADS_LOC(sdmmc, 15, 32 + 18);
PADS(emaca, 14);
PADS(bmp_syncport, 12);
PADS(slvmii, 11);
PADS(lcdc, 10);
PADS(lcdgp8, 8);
PADS(lcdgp7, 7);
PADS(lcdgp6, 6);
PADS(lcdgp5, 5);
PADS(lcdgp4, 4);
PADS(lcdgp3, 3);
PADS(lcdgp2, 2);
PADS(lcdgp1, 1);
PADS(lcdgp0, 0);

PADS(traceport, 32 + 19);
PADS(mema25, 32 + 14);
PADS(mema24, 32 + 13);
PADS(mema23, 32 + 12);
PADS(mema22, 32 + 11);
PADS(mema21, 32 + 10);
PADS(mema18, 32 + 9);
PADS(mema17, 32 + 8);
PADS(dclass, 32 + 7);
PADS(bmp, 32 + 6);
PADS(usb_drv_vbus, 32 + 5);
PADS(clk_out, 32 + 4);
PADS(ciu, 32 + 3);
PADS(qspi, 32 + 2);
PADS(ref_clk, 32 + 1);

static struct pads *pads[] = {
	&pads_rfapu,
	&pads_mlse,
	&pads_pmu,
	&pads_digmic,
	&pads_fc,
	&pads_uart1,
	&pads_uart2,
	&pads_tdm1,
	&pads_tdm2,
	&pads_spi1,
	&pads_spi2,
	&pads_i2c1,
	&pads_i2c2,
	&pads_sdmmc,
	&pads_emaca,
	&pads_bmp_syncport,
	&pads_slvmii,
	&pads_lcdc,
	&pads_lcdgp8,
	&pads_lcdgp7,
	&pads_lcdgp6,
	&pads_lcdgp5,
	&pads_lcdgp4,
	&pads_lcdgp3,
	&pads_lcdgp2,
	&pads_lcdgp1,
	&pads_lcdgp0,
	&pads_traceport,
	&pads_mema25,
	&pads_mema24,
	&pads_mema23,
	&pads_mema22,
	&pads_mema21,
	&pads_mema18,
	&pads_mema17,
	&pads_dclass,
	&pads_bmp,
	&pads_usb_drv_vbus,
	&pads_clk_out,
	&pads_ciu,
	&pads_qspi,
	&pads_ref_clk,
};


static struct pads *
pads_get(const char *id)
{
	int i;

	for (i = 0; i < ARRAY_SIZE(pads); i++) {
		if (!strcmp(id, pads[i]->name))
			return pads[i];
	}

	return NULL;
}

#define DVF99_SYSCFG_SPCR1 0x54
#define DVF99_SYSCFG_SPCR2 0x58

static void
pads_set_onoff(struct pads *pads, int on)
{
	int tmp, enable_bit, reg = DVF99_SYSCFG_SPCR2;

	enable_bit = pads->enable_bit;

	if (pads->enable_bit < 32)
		reg = DVF99_SYSCFG_SPCR1;
	else
		enable_bit -= 32;

	tmp = readl(DVF99_SYSCFG_BASE + reg);
	if (on)
		tmp |=  (1 << enable_bit);
	else
		tmp &= ~(1 << enable_bit);
	writel(tmp, DVF99_SYSCFG_BASE + reg);
}

static void
pads_set_location(struct pads *pads, int location)
{
	int tmp, reg = DVF99_SYSCFG_SPCR2;
	int location_bit = pads->location_bit;

	if (location_bit < 0)
		return;

	if (location_bit < 32)
		reg = DVF99_SYSCFG_SPCR1;
	else
		location_bit -= 32;

	tmp = readl(DVF99_SYSCFG_BASE + reg);
	if (location)
		tmp |=  (1 << location_bit);
	else
		tmp &= ~(1 << location_bit);
	writel(tmp, DVF99_SYSCFG_BASE + reg);
}

void
pads_enable(const char *id)
{
	struct pads *pads = pads_get(id);

	if (pads)
		pads_set_onoff(pads, 1);
}

void
pads_disable(const char *id)
{
	struct pads *pads = pads_get(id);

	if (pads)
		pads_set_onoff(pads, 0);
}

void
pads_location(const char *id, int location)
{
	struct pads *pads = pads_get(id);
	if (pads)
		pads_set_location(pads, location);
}
