/*
 *  linux/arch/arm/mach-dmw/arch.c
 *
 *  Copyright (C) 2010-2012 DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <linux/delay.h>
#include <linux/irq.h>
#include <linux/irqdomain.h>
#include <linux/of.h>
#include <linux/of_address.h>
#include <linux/of_irq.h>
#include <linux/of_platform.h>
#include <linux/regulator/machine.h>
#include <linux/dma-mapping.h>

#include <asm/mach/arch.h>
#include <asm/hardware/plicu.h>
#include <asm/mach/map.h>

#include <mach/hardware.h>
#include <mach/platform.h>
#include <generated/mach-types.h>

#include "clock.h"

static struct map_desc dmw_io_desc[] __initdata = {
	{
		.virtual	= IO_ADDRESS(DMW_CMU_BASE),
		.pfn		= __phys_to_pfn(DMW_CMU_BASE),
		.length		= SZ_4K,
		.type		= MT_DEVICE
	}, {
		.virtual	= IO_ADDRESS(DMW_SYSCFG_BASE),
		.pfn		= __phys_to_pfn(DMW_SYSCFG_BASE),
		.length		= SZ_4K,
		.type		= MT_DEVICE
	},
};

static const char *dmw_dt_match[] = {
	"dspg,dmw96",
	NULL
};

static const struct of_device_id plicu_of_match[] __initconst = {
	{ .compatible = "dspg,plicu", .data = plicu_init, },
	{ /* Sentinel */ }
};

static void __init dmw_map_io(void)
{
	init_consistent_dma_size(14 << 20);
	iotable_init(dmw_io_desc, ARRAY_SIZE(dmw_io_desc));
}

static void __init dmw_early_init(void)
{
	if (dmw_clk_init())
		panic("Clock init failed!");
}

static void __init dmw_init_irq(void)
{
	of_irq_init(plicu_of_match);
}

static void __init dmw_init_machine(void)
{
	regulator_has_full_constraints();
	of_platform_populate(NULL, of_default_bus_match_table, NULL, NULL);

	/*
	 * build-time check for correct CONSISTENT_DMA_SIZE; the SZ_4M is for
	 * the peripherals in dmw_io_desc[] (IO_ADDRESS() mappings start at
	 * VMALLOC_END).
	 */
	//BUILD_BUG_ON(VMALLOC_END + (SZ_4M) > CONSISTENT_BASE);
}

static void dmw_reset(char mode, const char *cmd)
{
	unsigned int value;

	/* Clear WDRSTIND and SWRSTIND before SW resetting */
	value = readl(IO_ADDRESS(DMW_CMU_BASE) + DMW_CMU_RSTSR);
	value |= (1<<5) | (1<<4) | (1<<3);
	writel(value, IO_ADDRESS(DMW_CMU_BASE) + DMW_CMU_RSTSR);

	writel(0x7496398B, IO_ADDRESS(DMW_CMU_BASE) + DMW_CMU_SWSYSRST);
	writel(0xB5C9C674, IO_ADDRESS(DMW_CMU_BASE) + DMW_CMU_SWSYSRST);
}

extern struct sys_timer dmw_timer;

MACHINE_START(DMW96, "DSPG DMW96")
	.map_io		= dmw_map_io,
	.nr_irqs	= NR_IRQS_LEGACY,
	.init_early	= dmw_early_init,
	.init_machine	= dmw_init_machine,
	.init_irq	= dmw_init_irq,
	.handle_irq	= plicu_handle_irq,
	.timer		= &dmw_timer,
	.dt_compat	= dmw_dt_match,
	.restart	= dmw_reset,
MACHINE_END

