/*
 *  linux/arch/arm/mach-dvf/include/mach/irqs.h
 *
 *  Copyright (C) 2010 DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __MACH_IRQS_H
#define __MACH_IRQS_H

#define DVF_PLICU_NR_IRQS		64

/* leave some room for the APU interrupts */
#define NR_IRQS				DVF_PLICU_NR_IRQS + 16

/* all interrupts can be FIQs */
#define FIQ_START			0

int dvf_trigger_sw_irq(unsigned int irq);
int dvf_set_irq_fiq(unsigned int irq, unsigned int type);

#define DVF_IID_MCU_ARM926				0
#define DVF_IID_CCU1_ERROR				1
#define DVF_IID_USB20OTG_SOF_PULSE		2
#define DVF_IID_USB20OTG_MC_NINT		3
#define DVF_IID_KEYPAD					4
#define DVF_IID_CCU0_ERROR				5
#define DVF_IID_CSS_NORMAL_INTERRUPT	6
#define DVF_IID_SECURITY_ACCELERATOR	7
#define DVF_IID_DRAM_CONTROLLER			8
#define DVF_IID_PMU_A2D_COMP			9
#define DVF_IID_PMU_BAT_OK				10
#define DVF_IID_PMU_INT_ANA				11
#define DVF_IID_CIU						12
#define DVF_IID_SLAVE_MII				13
#define DVF_IID_LCD_CONTROLLER			14
#define DVF_IID_SW1						15
#define DVF_IID_QSPI					16
#define DVF_IID_SDMMC_CONTROLLER		17
#define DVF_IID_USB11					18
#define DVF_IID_SEC						19
#define DVF_IID_GDMAC_ERROR				20
#define DVF_IID_GDMAC_DMA_DONE			21
#define DVF_IID_FLASH_CONTROLLER		22
#define DVF_IID_8023MAC					23
#define DVF_IID_EXTERNAL_REQUEST_0		24
#define DVF_IID_EXTERNAL_REQUEST_1		25
#define DVF_IID_EXTERNAL_REQUEST_2		26
#define DVF_IID_EXTERNAL_REQUEST_3		27
#define DVF_IID_EXTERNAL_REQUEST_4		28
#define DVF_IID_EXTERNAL_REQUEST_5		29
#define DVF_IID_EXTERNAL_REQUEST_6		30
#define DVF_IID_SW2						31
#define DVF_IID_EXTERNAL_REQUEST_7		32
#define DVF_IID_EXTERNAL_REQUEST_8		33
#define DVF_IID_EXTERNAL_REQUEST_9		34
#define DVF_IID_EXTERNAL_REQUEST_10		35
#define DVF_IID_EXTERNAL_REQUEST_11		36
#define DVF_IID_EXTERNAL_REQUEST_12		37
#define DVF_IID_EXTERNAL_REQUEST_13		38
#define DVF_IID_EXTERNAL_REQUEST_14		39
#define DVF_IID_EXTERNAL_REQUEST_15		40
#define DVF_IID_RTC						41
#define DVF_IID_I2C2					42
#define DVF_IID_I2C1					43
#define DVF_IID_SPI2					44
#define DVF_IID_SPI1					45
#define DVF_IID_TIMER4					46
#define DVF_IID_SW3						47
#define DVF_IID_TIMER3					48
#define DVF_IID_TIMER2					49
#define DVF_IID_TIMER1					50
#define DVF_IID_RESERVED51				51
#define DVF_IID_RESERVED52				52
#define DVF_IID_GPU						53
#define DVF_IID_UART2					54
#define DVF_IID_UART1					55
#define DVF_IID_RESERVED56				56
#define DVF_IID_RESERVED57				57
#define DVF_IID_RESERVED58				58
#define DVF_IID_TDM2					59
#define DVF_IID_TDM1					60
#define DVF_IID_RESERVED61				61
#define DVF_IID_WD						62
#define DVF_IID_SW4						63

#define DVF_IRQ_STRINGS \
	"mcu_arm926", \
	"ccu1_error", \
	"usb20otg_sof_pulse", \
	"usb20otg_mc_nint", \
	"keypad", \
	"ccu0_error", \
	"css_normal_interrupt", \
	"security_accelerator", \
	"pmu_a2d_comp", \
	"pmu_bat_ok", \
	"pmu_int_ana", \
	"ciu", \
	"slave_mii", \
	"lcd_controller", \
	"sw1", \
	"qspi", \
	"sdmmc_controller", \
	"usb11", \
	"sec", \
	"gdmac_error", \
	"gdmac_dma_done", \
	"flash_controller", \
	"8023mac", \
	"external_request_0", \
	"external_request_1", \
	"external_request_2", \
	"external_request_3", \
	"external_request_4", \
	"external_request_5", \
	"external_request_6", \
	"sw2", \
	"external_request_7", \
	"external_request_8", \
	"external_request_9", \
	"external_request_10", \
	"external_request_11", \
	"external_request_12", \
	"external_request_13", \
	"external_request_14", \
	"external_request_15", \
	"rtc", \
	"i2c2", \
	"i2c1", \
	"spi2", \
	"spi1", \
	"timer4", \
	"sw3", \
	"timer3", \
	"timer2", \
	"timer1", \
	"gpu", \
	"reserved51", \
	"reserved52", \
	"uart2", \
	"uart1", \
	"reserved56", \
	"reserved57", \
	"reserved58", \
	"tdm2", \
	"tdm1", \
	"reserved61", \
	"wd", \
	"sw4" 
#endif
