/*
 * linux/arch/arm/mach-dvf/include/mach/platform.h
 *
 * Copyright (c) 2010 DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __MACH_PLATFORM_H
#define __MACH_PLATFORM_H

/* Chip */
#define DVF_CHIP_UNKNOWN		-1
#define DVF_CHIP_DVF99			99
#define DVF_CHIP_DVF99_REV_A	0
#define DVF_CHIP_ANY			0x7fffffff

/* power management messages */
#define SEC_MSG_LATENCY			0
#define SEC_MSG_DRAM			1
#define SEC_MSG_PWR_DOWN		2
#define SEC_MSG_CLK_CMD			3
#define SEC_MSG_CLK_ARG			4
#define SEC_MSG_RST_CMD			5
/* reserved messages for COMA services */
#define SEC_MSG_COMA_START		16
#define SEC_MSG_COMA_END		32
/* panic message of the CSS side */
#define SEC_MSG_CSS_PANIC		40
#define SEC_MSG_CSS_RELOAD		41
#define SEC_MSG_CSS_COUNTER		42

#define DVF99_USB11_GCR1_VBUSEN				(1<<30)
#define DVF99_USB11_GCR1_CID				(1<<19)
#define DVF99_USB11_GCR1_VBUSVAL_MSK			(1<<18)
#define DVF99_USB11_GCR1_VBUSSES_MSK			(1<<17)
#define DVF99_USB11_GCR1_VBUSLO_MSK			(1<<16)
#define DVF99_USB11_GCR1_USB_PUDP_CTRL_PU_ACTIVATED_MSK	(1<<13)
#define DVF99_USB11_GCR1_USB_PUDP_CTRL_PD_ACTIVATED_MSK	(1<<12)
#define DVF99_USB11_GCR1_USB_PUM			(1<<9)
#define DVF99_USB11_GCR1_USB_PDM			(1<<8)
#define DVF99_USB11_GCR1_USB_BLOCK_RES_MSK		(1<<1)
#define DVF99_USB11_GCR1_USB_GLB_ON_MSK			(1<<0)

#ifndef __ASSEMBLER__
int dvf_get_chip(void);
int dvf_get_chip_rev(void);
char *dvf_board_get_type(void);
bool dvf_board_is(char *board);
bool dvf_board_has_feature(char *feature);
bool dvf_debug_disabled(void);
dma_addr_t dvf_dev_reserve_dmamem(struct device *dev, size_t size, int exclusive);
int dvf_get_usb11_gcr(void);
void dvf_set_usb11_gcr(int value);
#endif

/*
 * External interrupts - part of the GPIO block
 */
#define DVF_EXTINT_CFG				0x2A0
#define DVF_EXTINT_EDGE				0x2A4
#define DVF_EXTINT_STAT				0x2A8
#define DVF_EXTINT_EDGE_CLEAR		0x2AC

#endif
