/*
 *  linux/include/asm-arm/arch-dvf/uncompress.h
 *
 *  Copyright (C) 2010 DSPG Technologies GmbH
 *  Copyright (C) 2003 ARM Limited
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#define DVF_CMU_SWCLKENR1	(*(volatile unsigned char *)0x05300058)
#define UART1_EN			(1<<6)
#define UART2_EN			(1<<7)

#define DVF_UART1_BASE		0x05A00000
#define DVF_UART2_BASE		0x05B00000

#define DVF_UART_CTL			0x00
#define DVF_UART_TX_FIFO_LEVEL	0x24
#define DVF_UART_TX_DATA		0x2C

#define DVF_UART_CTL_EN			0x01

#define dvf_writeb(v,a)	(*(volatile unsigned char *)(a) = (v))
#define dvf_readb(a)	(*(volatile unsigned char *)(a))

/*
 * This does not append a newline
 */
static inline unsigned int get_base( void )
{
	unsigned int base = 0;

	if ((DVF_CMU_SWCLKENR1 & UART1_EN) &&
	    ((dvf_readb(DVF_UART1_BASE + DVF_UART_CTL)) & DVF_UART_CTL_EN))
		base = DVF_UART1_BASE;
	else if ((DVF_CMU_SWCLKENR1 & UART2_EN) &&
	    ((dvf_readb(DVF_UART2_BASE + DVF_UART_CTL)) & DVF_UART_CTL_EN))
		base = DVF_UART2_BASE;

	return base;
}

static inline void putc(int c)
{
	unsigned int base = get_base();

	if (!base)
		return;

	/* wait until there is space in TX FIFO */
	while (dvf_readb(base + DVF_UART_TX_FIFO_LEVEL) == 0x80)
		barrier();

	dvf_writeb(c, base + DVF_UART_TX_DATA);
}

static inline void flush(void)
{
	unsigned int base = get_base();

	if (!base)
		return;

	while (dvf_readb(base + DVF_UART_TX_FIFO_LEVEL))
		barrier();
}

/*
 * nothing to do
 */
#define arch_decomp_setup()
#define arch_decomp_wdog()

