/*
 *  linux/arch/arm/mach-dvf/time.c
 *
 *  Copyright (C) 2012, 2013 DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <linux/clksrc-dspg-rtc.h>
#include <linux/clksrc-dspg-timer.h>
#include <linux/err.h>
#include <linux/of.h>
#include <linux/of_address.h>
#include <linux/of_irq.h>
#include <linux/time.h>

#include <asm/mach/time.h>
#include <asm/sched_clock.h>

static struct dspg_rtc *rtc;
static struct dspg_tmr *tmr;

static u32 dvf_read_sched_clock(void)
{
	return dspg_rtc_read(rtc);
}

void read_persistent_clock(struct timespec *ts)
{
	if (rtc) {
		dspg_rtc_persistent_clock(rtc, ts);
	} else {
		ts->tv_sec = 0;
		ts->tv_nsec = 0;
	}
}

static const struct of_device_id dvf_rtc_ids[] __initconst = {
	{ .compatible = "dspg,rtc" },
	{ /* Sentinel */ },
};

static const struct of_device_id dvf_tmr_ids[] __initconst = {
	{ .compatible = "dspg,timer1" },
	{ /* Sentinel */ },
};

static void __init dvf_timer_init(void)
{
	struct device_node *rtc_node, *tmr_node;

	rtc_node = of_find_matching_node(NULL, dvf_rtc_ids);
	if (!rtc_node)
		panic("No RTC for sched clock to use");

	tmr_node = of_find_matching_node(NULL, dvf_tmr_ids);
	if (!tmr_node)
		panic("No timer for clockevents to use");

	rtc = dspg_rtc_init(rtc_node);
	if (IS_ERR(rtc))
		panic("dspg_rtc_init failed: %ld!", PTR_ERR(rtc));

	tmr = dspg_tmr_init(tmr_node);
	if (IS_ERR(tmr))
		panic("dspg_tmr_init failed: %ld!", PTR_ERR(tmr));

	of_node_put(rtc_node);
	of_node_put(tmr_node);

	dspg_rtc_register_clocksource(rtc);
	dspg_tmr_register_clockevent(tmr);
	setup_sched_clock(dvf_read_sched_clock, 32, dspg_rtc_rate(rtc));
}

struct sys_timer dvf_timer = {
	.init = dvf_timer_init,
};

