#!/bin/bash
. /opt/dspg/v1.2.6.1-rc2/environment-setup-armv5te-dspg-linux-uclibceabi 
CPU=`cat /proc/cpuinfo | grep -c processor`

check_status()
{
	if [ "$?" != "0" ]; then
		echo "**** Error: Build fails!"
		exit 1
	fi
}

usage() {
    echo "./build.sh <target>"
    echo "Valid Targets:"
    echo "`ls defconfig* | sed -e 's/defconfig_/\t/'`"
}

build_uimage() {
    echo "Building kernel image for defconfig_${1}"
    cp defconfig_$1 .config
    make ARCH=arm CROSS_COMPILE=arm-dspg-linux-uclibceabi- uImage -j$CPU
    check_status
    # cp .config defconfig_$1
    if [ -n "`echo $1 | grep nfs`" ]; then
        cp -v arch/arm/boot/uImage ../../../dvf9_gxp_image_build/gxp-build.cvscontrol/gxp_image_build/bin/core.gxp16xx.nfs
        if [ -f ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/core.gxp16xx.nfs ]; then
            cp -v arch/arm/boot/uImage ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/core.gxp16xx.nfs
        fi
    else
        cp -v arch/arm/boot/uImage ../../../dvf9_gxp_image_build/gxp-build.cvscontrol/gxp_image_build/bin/core.gxp16xx.dev
        if [ -f ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/core.gxp16xx.dev ]; then
            cp -v arch/arm/boot/uImage ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/core.gxp16xx.dev
        fi
    fi

    # make ARCH=arm CROSS_COMPILE=arm-dspg-linux-uclibceabi- modules -j$CPU
}

build_recovery() {
    cp defconfig_gxp_recovery .config
    make ARCH=arm CROSS_COMPILE=arm-dspg-linux-uclibceabi- uImage -j$CPU
    check_status
    make ARCH=arm CROSS_COMPILE=arm-dspg-linux-uclibceabi- uImage-dtb.gxp1625
    check_status

    cp -v arch/arm/boot/uImage-dtb.gxp1625 ../../../dvf9_gxp_image_build/gxp-build.cvscontrol/gxp_image_build/bin/recovery.gxp16xx.dev
    if [ -f ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/recovery.gxp16xx.dev ]; then
        cp -v arch/arm/boot/uImage-dtb.gxp1625 ../../../dvf9_gxp_image_build/gxp-build/gxp_image_build/bin/recovery.gxp16xx.dev
    fi
}

build_devtree() {
    cd devtree
    for i in `ls *.dts` ; do
        FILE=`echo $i | sed -e 's/\(.*\)\.dts/\1/'`
        ../scripts/dtc/dtc -I dts -O dtb -R 8 -p 0x3000 -o bin/$FILE.dtb $FILE.dts
    done
}

if [ x"$1" == x ]; then
    usage
    exit
elif [ "$1" = "gxp_recovery" ]; then
    build_recovery
    exit
else
    PRODUCTS=$1
fi

if [ ! -h include/provision.h ]; then
    ln -s ../../../../provision/provision.h include/provision.h
fi

for i in $PRODUCTS; do
    build_uimage $i
done

