/*
 * Copyright 2013 Grandstream Networks, Inc.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 */

#include <linux/err.h>
#include <linux/mutex.h>
#include <linux/module.h>
#include <linux/device.h>
#include <linux/platform_device.h>
#include <linux/gpio.h>
#include <linux/delay.h>
#include <linux/slab.h>
#include <linux/of.h>
#include <linux/of_gpio.h>

struct led_t
{
    char * name;
    unsigned int gpio;
};

static struct led_t led[] =
{
     {"LED_PHONE1", 0},
     {"LED_PHONE2", 0},
     {"LED_WAN", 0},
     {"LED_POWER", 0},
     {"LED_RJ45", 0}
};

#define NUM_LEDS ( sizeof ( led ) / sizeof ( struct led_t ) )

//=============================================================================
struct led_t *
gs_get_led_ptr(
    int * led_num
)
//=============================================================================
{
    *led_num = NUM_LEDS;

    return &led[0];
}
EXPORT_SYMBOL(gs_get_led_ptr);

//=============================================================================
int
gs_led_set(
    const char * led_name,
    const int on
)
//=============================================================================
{
    int i;

    for ( i = 0; i < NUM_LEDS; i++ )
    {
        if ( strcmp( led[i].name, led_name ) == 0 )
        {
            if ( on )
                gpio_set_value( led[i].gpio, 0);
            else
                gpio_set_value( led[i].gpio, 1);
            return 0;
        }
    }
    return -1;
}
EXPORT_SYMBOL(gs_led_set);

static int __devinit led_probe(struct platform_device *pdev) {
    struct led_t *drvdata;
    struct device_node *np = pdev->dev.of_node;
    int i;

    drvdata = &led[0];
    platform_set_drvdata(pdev, drvdata);

    for ( i = 0; i < NUM_LEDS; i ++ ) {
        drvdata[i].gpio = of_get_named_gpio(np, drvdata[i].name, 0);
        printk("%s: %s\n", drvdata[i].name, gpio_is_valid(drvdata[i].gpio) ? "valid" : "invalid");
        if (gpio_is_valid(drvdata[i].gpio)) {
            gpio_request(drvdata[i].gpio, "grandstream-led");
            gpio_direction_output(drvdata[i].gpio, 1);
        }
    }

    return 0;
}

static int __devexit led_remove(struct platform_device *pdev) {
    int i;
	struct led_t *drvdata = platform_get_drvdata(pdev);

    for ( i = 0; i < NUM_LEDS; i ++ ) {
        if (gpio_is_valid(drvdata[i].gpio))
            gpio_free(drvdata[i].gpio);
    }

    return 0;
}

static const struct of_device_id led_of_match[] __devinitconst = {
	{ .compatible = "grandstream,led", },
	{},
};
MODULE_DEVICE_TABLE(of, led_of_match);

static struct platform_driver gs_led_driver = {
	.probe		= led_probe,
	.remove		= __devexit_p(led_remove),
	.driver		= {
		.name		= "led-driver",
		.owner		= THIS_MODULE,
		.of_match_table = led_of_match, /* for historical reasons, this will remain as 'led' in the device tree */
	},
};

static int __init gs_led_init(void)
{
	return platform_driver_register(&gs_led_driver);
}
module_init(gs_led_init);

static void __exit gs_led_exit(void)
{
	platform_driver_unregister(&gs_led_driver);
}
module_exit(gs_led_exit);

MODULE_AUTHOR("Steven Frick (sfrick@grandstream.com)");
MODULE_DESCRIPTION("HRT Driver");
MODULE_LICENSE("GPL");
MODULE_ALIAS("platform:led-driver");
