/**
 * linux/drivers/net/dsa/rtl8363sb.c
 *
 *  Copyright (C) 2014 DSP Group
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/platform_device.h>
#include <linux/mii.h>
#include <linux/phy.h>
#include <linux/slab.h>
#include <linux/of.h>
#include <linux/of_mdio.h>
#include <net/dsa.h>
#include "../ethernet/stmicro/stmmac/stmmac.h"

#define MAX_NR_PORTS 4

static char *
rtl8363sb_dsa_probe(struct mii_bus *bus, int sw_addr)
{
	return "rtl8363sb";
}

static int
rtl8363sb_dsa_setup(struct dsa_switch *ds)
{
	return 0;
}

static int
rtl8363sb_dsa_set_addr(struct dsa_switch *ds, u8 *addr)
{
	return 0;
}

static int
rtl8363sb_smi_read(struct mii_bus *bus, int phy_id, int regnum)
{
	int err = 0;

	err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 31, 0x000e);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 23, regnum);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 21, 0x0001);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_read(bus, 0, 25);

	return err;
}

static int
rtl8363sb_smi_write(struct mii_bus *bus, int phy_id,
				int regnum, u16 val)
{
	int err = 0;

	err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 31, 0x000e);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 23, regnum);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 24, val);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 29, 0xffff);
	if (!err)
		err = stmmac_mdio_write(bus, 0, 21, 0x0003);

	return err;
}

static int
rtl8363sb_dsa_read(struct dsa_switch *ds, int port, int regnum)
{
	int err = 0;

	if (port > MAX_NR_PORTS)
		return 0xffff;

	err = rtl8363sb_smi_write(ds->master_mii_bus, 0, 0x2000 + (port << 5) + 31, 0);
	if (!err)
		err = rtl8363sb_smi_read(ds->master_mii_bus, 0, 0x2000 + (port << 5) + regnum);

	return err;
}

static int
rtl8363sb_dsa_write(struct dsa_switch *ds, int port, int regnum, u16 val)
{
	int err = 0;

	if (port > MAX_NR_PORTS)
		return 0xffff;

	err = rtl8363sb_smi_write(ds->master_mii_bus, 0, 0x2000 + (port << 5) + 31, 0);
	if (!err)
		err = rtl8363sb_smi_write(ds->master_mii_bus, 0, 0x2000 + (port << 5) + regnum, val);

	return err;
}

static struct dsa_switch_driver rtl8363sb_switch_driver = {
	.tag_protocol	= htons(ETH_P_EDSA),
	.probe		= rtl8363sb_dsa_probe,
	.setup		= rtl8363sb_dsa_setup,
	.set_addr	= rtl8363sb_dsa_set_addr,
	.phy_read	= rtl8363sb_dsa_read,
	.phy_write	= rtl8363sb_dsa_write,
};

static int __devinit rtl8363sb_probe(struct platform_device *pdev)
{
	register_switch_driver(&rtl8363sb_switch_driver);

	return 0;
}

static int rtl8363sb_remove(struct platform_device *pdev)
{
	return 0;
}

static const struct of_device_id rtl8363sb_dt_ids[] = {
	{ .compatible = "rtl8363sb,dsa", },
	{ /* sentinel */ }
};
MODULE_DEVICE_TABLE(of, rtl8363sb_dt_ids);

static struct platform_driver rtl8363sb_driver = {
	.probe = rtl8363sb_probe,
	.remove = rtl8363sb_remove,
	.driver = {
		.name = "RTL8363SB",
		.owner = THIS_MODULE,
		.of_match_table = of_match_ptr(rtl8363sb_dt_ids),
	},
};

module_platform_driver(rtl8363sb_driver);

MODULE_DESCRIPTION("Realtek 8363SB DSA driver");
MODULE_AUTHOR("DSPG");
MODULE_LICENSE("GPL");

