/*
 * drivers/staging/dspg/coma/cmsg-crypto.h - crypto cmsg layer
 *
 *  Copyright (C) 2012 DSP Group Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef CMSG_CRYPTO_H
#define CMSG_CRYPTO_H

enum cmsg_crypto_types {
	CMSG_CRYPTO_OPEN = 0,
	CMSG_CRYPTO_OPEN_REPLY,
	CMSG_CRYPTO_CLOSE,
	CMSG_CRYPTO_CLOSE_REPLY,
	CMSG_CRYPTO_START,
	CMSG_CRYPTO_DONE,
};

enum crypto_actions {
	ACTION_ENCRYPT = 0,
	ACTION_DECRYPT,
	ACTION_LAST,
};

enum crypto_algorithm {
	ALGORITHM_AES_GCM = 0,
	ALGORITHM_LAST,
};

#define CRYPTO_FLAG_SIGNAL               (1 << 0)

union cmsg_crypto_params {
	/* CMSG_CRYPTO_OPEN */
	struct crypto_open {
		unsigned int algorithm;
	} crypto_open;
	/* CMSG_CRYPTO_OPEN_REPLY */
	struct crypto_open_reply {
		int status;
	} crypto_open_reply;
	/* CMSG_CRYPTO_CLOSE */
	struct crypto_close {
		unsigned int session;
	} crypto_close;
	/* CMSG_CRYPTO_CLOSE_REPLY */
	struct crypto_close_reply {
		int status;
	} crypto_close_reply;
	/* CMSG_CRYPTO_START */
	struct crypto_start {
		unsigned int session;
		unsigned int action;
		unsigned int flags;
		int *finished;
		unsigned int iv_len;
		void *iv;
		unsigned int key_len;
		void *key;
		unsigned int data_len;
		void *data;
	} crypto_start;
};

#endif
