/*
 * drivers/staging/dspg/coma/coma-sharedmem.h - shared memory allocation service
 *
 * Copyright (C) 2013 DSP Group Inc.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _COMA_SHAREDMEM_H
#define _COMA_SHAREDMEM_H

struct sharedmem_coma_handle {
	unsigned long addr;
	unsigned long pa;
	unsigned int size;
};

#define SHAREDMEM_IOC_MAGIC	'S'
#define SHAREDMEM_IOCALLOC	_IOWR(SHAREDMEM_IOC_MAGIC, 0, struct sharedmem_coma_handle *)
#define SHAREDMEM_IOCFREE	_IOWR(SHAREDMEM_IOC_MAGIC, 1, struct sharedmem_coma_handle *)
#define SHAREDMEM_IOC_MAXNR	1

#ifdef CONFIG_DSPG_CSS_SHAREDMEM
int   sharedmem_coma_service_init(struct device *dev, dma_addr_t base,
				  size_t size);
void *sharedmem_coma_alloc(size_t size, dma_addr_t *handle);
int   sharedmem_coma_free(size_t size, void *cpu_addr, dma_addr_t handle);
int   sharedmem_is_shared(void *addr);
#else
#include <linux/errno.h>
#include <linux/dma-mapping.h>

static inline int sharedmem_coma_service_init(struct device *dev,
					      dma_addr_t base, size_t size)
{
	return 0;
}
static inline void *sharedmem_coma_alloc(size_t size, dma_addr_t *handle)
{
	return NULL;
}
static inline int sharedmem_coma_free(size_t size, void *cpu_addr, dma_addr_t handle)
{
	return -1;
}
static inline int sharedmem_is_shared(void *addr)
{
	return 0;
}
#endif

#endif /* _COMA_SHAREDMEM_H */
