/*
 * DSPG DVF9A ALSA DAIF driver
 *
 * Copyright (c) 2012, DSP Group
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 as
 * published by the Free Software Foundation.
 */

#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/err.h>
#include <linux/io.h>
#include <linux/irq.h>
#include <linux/irqdomain.h>
#include <linux/interrupt.h>
#include <linux/clk.h>
#include <linux/slab.h>
#include <linux/platform_device.h>
#include <linux/mfd/core.h>
#include <linux/mfd/dvf9a.h>
#include <linux/of.h>
#include "alsa-dvf9a.h"

#define ALSA_DVF9A "dvf9a-alsa"

struct dvf9a_alsa {
	struct dvf9a *dvf9a;
	struct platform_device *pdev;
};

struct dvf9a_alsa *dvf9a_alsa;

int dvf9a_alsa_daif_read(int reg)
{
	if (dvf9a_alsa)
		return daif_read(dvf9a_alsa->dvf9a,reg);
	return -1;
}
EXPORT_SYMBOL_GPL(dvf9a_alsa_daif_read);

void dvf9a_alsa_daif_write(int reg, int val)
{
	if (dvf9a_alsa)
		daif_write(dvf9a_alsa->dvf9a, reg, val);
}
EXPORT_SYMBOL_GPL(dvf9a_alsa_daif_write);

static int
dvf9a_alsa_probe(struct platform_device *pdev)
{
	struct dvf9a *dvf9a = dev_get_drvdata(pdev->dev.parent);

	dvf9a_alsa = kzalloc(sizeof *dvf9a_alsa, GFP_KERNEL);
	if (!dvf9a_alsa) {
		dev_err(&pdev->dev, "Out of memory\n");
		return -ENOMEM;
	}
	dvf9a_alsa->pdev = pdev;
	dvf9a_alsa->dvf9a = dvf9a;

	platform_set_drvdata(pdev, dvf9a_alsa);
	dev_info(&pdev->dev, "successfully registered\n");

	return 0;
}

static int __exit
dvf9a_alsa_remove(struct platform_device *dev)
{
	kfree(dvf9a_alsa);
	dvf9a_alsa = NULL;

	return 0;
}

static struct of_device_id dvf9a_alsa_of_ids[] = {
	{ .compatible = "dspg,dvf9a-alsa" },
	{ },
};

static struct platform_driver dvf9a_alsa_platform_driver = {
	.driver = {
		.name	= ALSA_DVF9A,
		.owner	= THIS_MODULE,
		.of_match_table = dvf9a_alsa_of_ids,
	},
	.probe		= dvf9a_alsa_probe,
	.remove		= __exit_p(dvf9a_alsa_remove),
};

static int __init
dvf9a_alsa_init(void)
{
	return platform_driver_register(&dvf9a_alsa_platform_driver);
}
module_init(dvf9a_alsa_init);

static void __exit
dvf9a_alsa_exit(void)
{
	platform_driver_unregister(&dvf9a_alsa_platform_driver);
}
module_exit(dvf9a_alsa_exit);

MODULE_DESCRIPTION("DSPG DVF9A-ALSA driver");
MODULE_LICENSE("GPL v2");
MODULE_AUTHOR("DSP Group");
MODULE_ALIAS("platform:dvf9a-alsa");
