/*
 *snd-dvf99-cpu-dai.c -- ASoC cpu dai Driver for DVF99 DSPG-style board,
 * with CSS codec.
 *
 *  Copyright (C) 2011 DSPG Technologies GmbH
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <linux/io.h>
#include <linux/module.h>
#include <linux/slab.h>
#include <mach/platform.h>
#include <mach/gpio.h>
#include <asm/atomic.h>
#include <sound/core.h>
#include <sound/pcm.h>
#include <sound/soc.h>
#include <sound/soc-dapm.h>
#include <linux/of.h>

#define DRIVER_NAME "snd-cpu-dai"
#define DEVICE_NAME "dvf99_cpu_dai"
#define DUMMY_FORMATS   (SNDRV_PCM_FMTBIT_S8 | SNDRV_PCM_FMTBIT_S16_LE)
#define DUMMY_RATES     (SNDRV_PCM_RATE_8000_96000)

static struct snd_soc_dai_driver dvf_cpu_dais[] = {
	/* PCM HD -- only for playback */
	{
		.name = "CSS",
		.id = 0,
		.playback = {
			.channels_min   = 1,
			.channels_max   = 2,
			.rates          = DUMMY_RATES,
			.formats        = DUMMY_FORMATS,
		},
		.capture = {
			.channels_min   = 1,
			.channels_max   = 3,
			.rates          = DUMMY_RATES,
			.formats        = DUMMY_FORMATS,
		},
	},
};

static int
dspg_snd_probe(struct platform_device *pdev)
{
	return snd_soc_register_dais(&pdev->dev, dvf_cpu_dais, 1);
}

static int
dspg_snd_remove(struct platform_device *pdev)
{
	return 0;
}

static struct of_device_id snd_cpu_dai_of_ids[] = {
	{ .compatible = "dspg,snd-cpu-dai" },
	{ },
};

static struct platform_driver dvf99_cpu_dai_drv = {
	.driver = {
		.name = DRIVER_NAME,
		.owner = THIS_MODULE,
		.of_match_table = snd_cpu_dai_of_ids,
	},
	.probe = dspg_snd_probe,
	.remove = __devexit_p(dspg_snd_remove),
};

static int __init
dvf99_cpu_dai_mod_init(void)
{
	return platform_driver_register(&dvf99_cpu_dai_drv);
}
module_init(dvf99_cpu_dai_mod_init);

static void __exit
dvf99_cpu_dai_mod_exit(void)
{
	platform_driver_unregister(&dvf99_cpu_dai_drv);
}
module_exit(dvf99_cpu_dai_mod_exit);

MODULE_DESCRIPTION("ASoC cpu dai driver for DSPG DVF99 board");
MODULE_AUTHOR("DSP Group");
MODULE_LICENSE("GPL");
